==> RISmed_2.0.1.tar.gz: RISmed/R/AllGenerics.R <==
# RISmed GENERICS
setGeneric("QueryCount",function(object) standardGeneric("QueryCount"))
setGeneric("QueryId",function(object) standardGeneric("QueryId"))
setGeneric("QueryTranslation",function(object) standardGeneric("QueryTranslation"))

setGeneric("Query",function(object) standardGeneric("Query"))                                
setGeneric("PMID",function(object) standardGeneric("PMID"))                                
setGeneric("Year",function(object) standardGeneric("Year"))                                
setGeneric("Month",function(object) standardGeneric("Month"))                              
setGeneric("Day",function(object) standardGeneric("Day"))                                  
setGeneric("Author",function(object) standardGeneric("Author"))                            
setGeneric("ISSN",function(object) standardGeneric("ISSN"))                                
setGeneric("Title",function(object) standardGeneric("Title"))                              
setGeneric("ArticleTitle",function(object) standardGeneric("ArticleTitle"))                
setGeneric("ELocationID",function(object) standardGeneric("ELocationID"))                  
setGeneric("AbstractText",function(object) standardGeneric("AbstractText"))                
setGeneric("Affiliation",function(object) standardGeneric("Affiliation"))                  
setGeneric("Language",function(object) standardGeneric("Language"))                        
setGeneric("PublicationType",function(object) standardGeneric("PublicationType"))          
setGeneric("MedlineTA",function(object) standardGeneric("MedlineTA"))                      
setGeneric("NlmUniqueID",function(object) standardGeneric("NlmUniqueID"))                  
setGeneric("ISSNLinking",function(object) standardGeneric("ISSNLinking"))                  
setGeneric("Hour",function(object) standardGeneric("Hour"))                                
setGeneric("Minute",function(object) standardGeneric("Minute"))                            
setGeneric("PublicationStatus",function(object) standardGeneric("PublicationStatus"))      
setGeneric("ArticleId",function(object) standardGeneric("ArticleId"))                      
setGeneric("Volume",function(object) standardGeneric("Volume"))                            
setGeneric("Issue",function(object) standardGeneric("Issue"))                              
setGeneric("ISOAbbreviation",function(object) standardGeneric("ISOAbbreviation"))          
setGeneric("MedlinePgn",function(object) standardGeneric("MedlinePgn"))                    
setGeneric("CopyrightInformation",function(object) standardGeneric("CopyrightInformation"))
setGeneric("Country",function(object) standardGeneric("Country"))                          
setGeneric("DescriptorName",function(object) standardGeneric("DescriptorName"))            
setGeneric("QualifierName",function(object) standardGeneric("QualifierName"))              
setGeneric("GrantID",function(object) standardGeneric("GrantID"))                          
setGeneric("Acronym",function(object) standardGeneric("Acronym"))                          
setGeneric("Agency",function(object) standardGeneric("Agency"))                            
setGeneric("RegistryNumber",function(object) standardGeneric("RegistryNumber"))            
setGeneric("RefSource",function(object) standardGeneric("RefSource"))                      
setGeneric("CollectiveName",function(object) standardGeneric("CollectiveName"))

==> RISmed_2.1.0.tar.gz: RISmed/R/AllGenerics.R <==
# RISmed GENERICS
setGeneric("QueryCount",function(object) standardGeneric("QueryCount"))
setGeneric("QueryId",function(object) standardGeneric("QueryId"))
setGeneric("QueryTranslation",function(object) standardGeneric("QueryTranslation"))
setGeneric("Query",function(object) standardGeneric("Query"))                                
setGeneric("PMID",function(object) standardGeneric("PMID"))                                
setGeneric("Year",function(object) standardGeneric("Year"))                                
setGeneric("Month",function(object) standardGeneric("Month"))                              
setGeneric("Day",function(object) standardGeneric("Day"))                                  
setGeneric("Author",function(object) standardGeneric("Author"))                            
setGeneric("ISSN",function(object) standardGeneric("ISSN"))                                
setGeneric("Title",function(object) standardGeneric("Title"))                              
setGeneric("ArticleTitle",function(object) standardGeneric("ArticleTitle"))                
setGeneric("ELocationID",function(object) standardGeneric("ELocationID"))                  
setGeneric("AbstractText",function(object) standardGeneric("AbstractText"))                
setGeneric("Affiliation",function(object) standardGeneric("Affiliation"))                  
setGeneric("Language",function(object) standardGeneric("Language"))                        
setGeneric("PublicationType",function(object) standardGeneric("PublicationType"))          
setGeneric("MedlineTA",function(object) standardGeneric("MedlineTA"))                      
setGeneric("NlmUniqueID",function(object) standardGeneric("NlmUniqueID"))                  
setGeneric("ISSNLinking",function(object) standardGeneric("ISSNLinking"))                  
setGeneric("Hour",function(object) standardGeneric("Hour"))                                
setGeneric("Minute",function(object) standardGeneric("Minute"))                            
setGeneric("PublicationStatus",function(object) standardGeneric("PublicationStatus"))      
setGeneric("ArticleId",function(object) standardGeneric("ArticleId"))                      
setGeneric("Volume",function(object) standardGeneric("Volume"))                            
setGeneric("Issue",function(object) standardGeneric("Issue"))                              
setGeneric("ISOAbbreviation",function(object) standardGeneric("ISOAbbreviation"))          
setGeneric("MedlinePgn",function(object) standardGeneric("MedlinePgn"))                    
setGeneric("CopyrightInformation",function(object) standardGeneric("CopyrightInformation"))
setGeneric("Country",function(object) standardGeneric("Country"))                          
setGeneric("GrantID",function(object) standardGeneric("GrantID"))                          
setGeneric("Acronym",function(object) standardGeneric("Acronym"))                          
setGeneric("Agency",function(object) standardGeneric("Agency"))                            
setGeneric("RegistryNumber",function(object) standardGeneric("RegistryNumber"))            
setGeneric("RefSource",function(object) standardGeneric("RefSource"))                      
setGeneric("CollectiveName",function(object) standardGeneric("CollectiveName"))
setGeneric("Mesh",function(object) standardGeneric("Mesh"))
